﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation either version
 * 2 of the License, or (at your option) any later version.
 * 
 * ExtremeML is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using System.Collections.Generic;

namespace ExtremeML.Builder
{
	/// <summary>
	/// Encapsulates the usage parameters for a custom generated code pattern.
	/// </summary>
	public class CustomPattern
	{
		public CustomPattern(
			string name)
		{
			Name = name;
			Arguments = new Dictionary<string, string>();
		}
		
		/// <summary>
		/// Gets the name of the custom pattern associated with this instance.
		/// </summary>
		public string Name { get; private set; }

		/// <summary>
		/// Gets or sets whether the associated pattern uses event listeners.
		/// </summary>
		public bool HasEventListeners { get; set; }

		/// <summary>
		/// Gets or sets the code generation arguments required by the associated pattern.
		/// </summary>
		public Dictionary<string, string> Arguments { get; set; }
	}
}
