﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation either version
 * 2 of the License, or (at your option) any later version.
 * 
 * ExtremeML is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using System;

namespace ExtremeML.Builder
{
	/// <summary>
	/// Maps an SDK simple type to its corresponding framework type and
	/// stores expression templates for conversion between the two.
	/// </summary>
	public class SimpleTypeMapping
	{
		/// <summary>
		/// Gets or sets the OpenXml SDK <see cref="Type"/> targeted by this mapping.
		/// </summary>
		public Type SdkType { get; set; }

		/// <summary>
		/// Gets or sets the .Net Framework <see cref="Type"/> targeted by this mapping.
		/// </summary>
		public Type FrameworkType { get; set; }

		/// <summary>
		/// Gets or sets the expression template used to convert a .Net Framework type instance to its mapped SDK type.
		/// </summary>
		public string ToSdkTypeExpression { get; set; }

		/// <summary>
		/// Gets or sets the expression template used to convert a SDK type instance to its mapped .Net Framework type.
		/// </summary>
		public string ToFrameworkTypeExpression { get; set; }
	}
}
