﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public
 * License, as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using DocumentFormat.OpenXml.Packaging;
using ExtremeML.Spreadsheet;

namespace ExtremeML.Packaging
{
	// This is a partial class that adds custom functionality to its auto-generated partner.
	public sealed partial class TableDefinitionPartWrapperCollection
	{
		#region Custom Properties

		/// <summary>
		/// Gets the containing package as a <see cref="SpreadsheetDocumentWrapper"/>.
		/// </summary>
		public SpreadsheetDocumentWrapper Spreadsheet
		{
			get { return (SpreadsheetDocumentWrapper)Package; }
		}

		/// <summary>
		/// Gets the containing <see cref="WorksheetWrapper"/>.
		/// </summary>
		public WorksheetWrapper Worksheet
		{
			get { return ((WorksheetPartWrapper)Parent).Worksheet; }
		}

//ToDo: This should be implemented as the UniquelyNamedCollectionPattern
		/// <summary>
		/// Gets a <see cref="TableDefinitionPartWrapper"/> by the name of the
		/// table contained within its wrapped <see cref="TableDefinitionPart"/>.
		/// </summary>
		public TableDefinitionPartWrapper this[string name]
		{
			get { return Items.Find(item => item.Table.Name == name); }
		}

		#endregion
		#region Custom Methods


		#endregion
		#region Overrides

		/// <summary>
		/// Performs housekeeping and validation of a collection member addition.
		/// </summary>
		protected override void OnCustomAdding(
			TableDefinitionPartWrapper part)
		{
			Worksheet.TableParts.TableParts.Add(part.Id);
		}

		/// <summary>
		/// Performs housekeeping and validation of a requested deletion.
		/// </summary>
		protected override bool OnCustomRemoving(
			TableDefinitionPartWrapper part)
		{
			Worksheet.TableParts.TableParts.Delete(part.Id);
			return true;
		}

		#endregion
		#region Implementation Methods


		#endregion
		#region Static Methods


		#endregion
	}
}
