﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public
 * License, as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using System;

namespace ExtremeML.Spreadsheet.Address
{
	/// <summary>
	/// Parses and decomposes a native cell reference string and provides methods to extract other cell addressing types.
	/// </summary>
	public struct GridReference
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="GridReference"/> struct.
		/// </summary>
		/// <param name="rowIndex">The zero-based index of the row associated with the target cell.</param>
		/// <param name="columnIndex">The zero-based index of the column associated with the target cell.</param>
		public GridReference(
			int rowIndex,
			int columnIndex) : this()
		{
			if (rowIndex < 0) throw new ArgumentOutOfRangeException("rowIndex");
			if (columnIndex < 0) throw new ArgumentOutOfRangeException("columnIndex");

			RowIndex = rowIndex;
			ColumnIndex = columnIndex;
		}

		/// <summary>
		/// Gets the zero-based index of the row associated with the target cell.
		/// </summary>
		public int RowIndex { get; private set; }

		/// <summary>
		/// Gets the zero-based index of the column associated with the target cell.
		/// </summary>
		public int ColumnIndex { get; private set; }
	}
}
