﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public
 * License, as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using System;

namespace ExtremeML.Spreadsheet.Address
{
	/// <summary>
	/// Provides data for the events that notify changes to the size of a cell range.
	/// </summary>
	internal class RangeResizeEventArgs : EventArgs
	{
		/// <summary>
		/// Initializes a new instance of the <see cref="RangeResizeEventArgs"/> class.
		/// </summary>
		/// <param name="index">The zero-based index of the row or column where insertion or deletion is anchored.</param>
		/// <param name="count">The number or rows or columns to be inserted or deleted.</param>
		public RangeResizeEventArgs(
			int index,
			int count)
		{
			if (index < 0) throw new ArgumentOutOfRangeException("index");
			if (count < 0) throw new ArgumentOutOfRangeException("count");

			Index = index;
			Count = count;
		}

		/// <summary>
		/// Gets the zero-based index of the row or column where insertion or deletion is anchored.
		/// </summary>
		public int Index { get; private set; }

		/// <summary>
		/// Gets the number or rows or columns to be inserted or deleted.
		/// </summary>
		public int Count { get; private set; }
	}
}
