﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public
 * License, as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using DocumentFormat.OpenXml.Spreadsheet;

namespace ExtremeML.Spreadsheet
{
	// This is a partial class that adds custom functionality to its auto-generated partner.
	public sealed partial class TablePartWrapperCollection
	{
		#region Custom Properties


		#endregion
		#region Custom Methods

		/// <summary>
		/// Returns the wrapper for the table part having the specified id.
		/// </summary>
		/// <param name="id">The id of the target table part.</param>
		/// <returns>A <see cref="TablePartWrapper"/> that matches the specified id. <c>null</c> if no match is found.</returns>
		internal TablePartWrapper Find(
			string id)
		{
			return Items.Find(item => item.Id == id);
		}

		/// <summary>
		/// Returns a <see cref="TablePartWrapper"/> that wraps a new <see cref="TablePart"/>
		/// with the specified table definition part relationship id.
		/// </summary>
		/// <param name="id">The identifier of the table definition part where the definition for this table is stored.</param>
		/// <returns>A new instance of <see cref="TablePartWrapper"/>.</returns>
		internal TablePartWrapper Add(
			string id)
		{
			var result = Add();
			result.Id = id;
			result.Activate();
			return result;
		}

		/// <summary>
		/// Deletes the <see cref="TablePartWrapper"/> that wraps the table part having the specified relationship id.
		/// </summary>
		/// <param name="id">The id of the target table part.</param>
		internal void Delete(
			string id)
		{
			Items.Remove(Items.Find(item => item.Id == id));
		}	

		#endregion
		#region Overrides


		#endregion
		#region Implementation Methods


		#endregion
		#region Static Methods


		#endregion
	}
}
