﻿#region License
/* Copyright (C) 2009 Tim Coulter
 * 
 * This file is part of ExtremeML.
 * 
 * ExtremeML is free software: you can redistribute
 * it and/or modify it under the terms of the GNU General Public
 * License, as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
 * the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
*/
#endregion

using DocumentFormat.OpenXml;
using DocumentFormat.OpenXml.Spreadsheet;

namespace ExtremeML.Spreadsheet
{
	// This is a partial class that adds custom functionality to its auto-generated partner.
	public sealed partial class TextWrapper
	{
		#region Custom Properties

		private string _value;

		/// <summary>
		/// Gets or sets the contained value.
		/// </summary>
		public string Value
		{
			get { return _value; }
			set { SetModified(value, _value); _value = value; }
		}

		#endregion
		#region Custom Methods


		#endregion
		#region Overrides

		/// <summary>
		/// Implements custom initialization functionality.
		/// </summary>
		protected override void OnCustomInitializing()
		{
			_value = default(string);
		}

		/// <summary>
		/// Implements custom population functionality.
		/// </summary>
		protected override void OnCustomDecomposing()
		{
			_value = Wrapped.Text;
		}

		/// <summary>
		/// Implements custom persistence functionality.
		/// </summary>
		protected override void OnCustomRecomposed(
			Text wrapped)
		{
			wrapped.Text = _value;
		}

		#endregion
		#region Implementation Methods


		#endregion
		#region Static Methods

		/// <summary>
		/// Returns a value that represents default element content.
		/// </summary>
		/// <returns>A new <see cref="RunProperties"/> instance.</returns>
		internal static new Text CreateDefaultElement()
		{
			return new Text() { Space = SpaceProcessingModeValues.Preserve };
		}

		#endregion
	}
}
